RegisterBlock

Struct RegisterBlock 

pub struct RegisterBlock { /* private fields */ }
Register block

Implementations

Source

impl RegisterBlock

pub const fn gcfg(&self) -> &Gcfg

0x00 - DMAC Global Configuration Register

pub const fn en(&self) -> &En

0x04 - DMAC Enable Register

pub const fn sreq(&self) -> &Sreq

0x08 - DMAC Software Single Request Register

pub const fn creq(&self) -> &Creq

0x0c - DMAC Software Chunk Transfer Request Register

pub const fn last(&self) -> &Last

0x10 - DMAC Software Last Transfer Flag Register

pub const fn ebcier(&self) -> &Ebcier

0x18 - DMAC Error, Chained Buffer Transfer Completed Interrupt and Buffer Transfer Completed Interrupt Enable register.

pub const fn ebcidr(&self) -> &Ebcidr

0x1c - DMAC Error, Chained Buffer Transfer Completed Interrupt and Buffer Transfer Completed Interrupt Disable register.

pub const fn ebcimr(&self) -> &Ebcimr

0x20 - DMAC Error, Chained Buffer Transfer Completed Interrupt and Buffer transfer completed Mask Register.

pub const fn ebcisr(&self) -> &Ebcisr

0x24 - DMAC Error, Chained Buffer Transfer Completed Interrupt and Buffer transfer completed Status Register.

pub const fn cher(&self) -> &Cher

0x28 - DMAC Channel Handler Enable Register

pub const fn chdr(&self) -> &Chdr

0x2c - DMAC Channel Handler Disable Register

pub const fn chsr(&self) -> &Chsr

0x30 - DMAC Channel Handler Status Register

pub const fn saddr0(&self) -> &Saddr0

0x3c - DMAC Channel Source Address Register (ch_num = 0)

pub const fn daddr0(&self) -> &Daddr0

0x40 - DMAC Channel Destination Address Register (ch_num = 0)

pub const fn dscr0(&self) -> &Dscr0

0x44 - DMAC Channel Descriptor Address Register (ch_num = 0)

pub const fn ctrla0(&self) -> &Ctrla0

0x48 - DMAC Channel Control A Register (ch_num = 0)

pub const fn ctrlb0(&self) -> &Ctrlb0

0x4c - DMAC Channel Control B Register (ch_num = 0)

pub const fn cfg0(&self) -> &Cfg0

0x50 - DMAC Channel Configuration Register (ch_num = 0)

pub const fn saddr1(&self) -> &Saddr1

0x64 - DMAC Channel Source Address Register (ch_num = 1)

pub const fn daddr1(&self) -> &Daddr1

0x68 - DMAC Channel Destination Address Register (ch_num = 1)

pub const fn dscr1(&self) -> &Dscr1

0x6c - DMAC Channel Descriptor Address Register (ch_num = 1)

pub const fn ctrla1(&self) -> &Ctrla1

0x70 - DMAC Channel Control A Register (ch_num = 1)

pub const fn ctrlb1(&self) -> &Ctrlb1

0x74 - DMAC Channel Control B Register (ch_num = 1)

pub const fn cfg1(&self) -> &Cfg1

0x78 - DMAC Channel Configuration Register (ch_num = 1)

pub const fn saddr2(&self) -> &Saddr2

0x8c - DMAC Channel Source Address Register (ch_num = 2)

pub const fn daddr2(&self) -> &Daddr2

0x90 - DMAC Channel Destination Address Register (ch_num = 2)

pub const fn dscr2(&self) -> &Dscr2

0x94 - DMAC Channel Descriptor Address Register (ch_num = 2)

pub const fn ctrla2(&self) -> &Ctrla2

0x98 - DMAC Channel Control A Register (ch_num = 2)

pub const fn ctrlb2(&self) -> &Ctrlb2

0x9c - DMAC Channel Control B Register (ch_num = 2)

pub const fn cfg2(&self) -> &Cfg2

0xa0 - DMAC Channel Configuration Register (ch_num = 2)

pub const fn saddr3(&self) -> &Saddr3

0xb4 - DMAC Channel Source Address Register (ch_num = 3)

pub const fn daddr3(&self) -> &Daddr3

0xb8 - DMAC Channel Destination Address Register (ch_num = 3)

pub const fn dscr3(&self) -> &Dscr3

0xbc - DMAC Channel Descriptor Address Register (ch_num = 3)

pub const fn ctrla3(&self) -> &Ctrla3

0xc0 - DMAC Channel Control A Register (ch_num = 3)

pub const fn ctrlb3(&self) -> &Ctrlb3

0xc4 - DMAC Channel Control B Register (ch_num = 3)

pub const fn cfg3(&self) -> &Cfg3

0xc8 - DMAC Channel Configuration Register (ch_num = 3)

pub const fn saddr4(&self) -> &Saddr4

0xdc - DMAC Channel Source Address Register (ch_num = 4)

pub const fn daddr4(&self) -> &Daddr4

0xe0 - DMAC Channel Destination Address Register (ch_num = 4)

pub const fn dscr4(&self) -> &Dscr4

0xe4 - DMAC Channel Descriptor Address Register (ch_num = 4)

pub const fn ctrla4(&self) -> &Ctrla4

0xe8 - DMAC Channel Control A Register (ch_num = 4)

pub const fn ctrlb4(&self) -> &Ctrlb4

0xec - DMAC Channel Control B Register (ch_num = 4)

pub const fn cfg4(&self) -> &Cfg4

0xf0 - DMAC Channel Configuration Register (ch_num = 4)

pub const fn saddr5(&self) -> &Saddr5

0x104 - DMAC Channel Source Address Register (ch_num = 5)

pub const fn daddr5(&self) -> &Daddr5

0x108 - DMAC Channel Destination Address Register (ch_num = 5)

pub const fn dscr5(&self) -> &Dscr5

0x10c - DMAC Channel Descriptor Address Register (ch_num = 5)

pub const fn ctrla5(&self) -> &Ctrla5

0x110 - DMAC Channel Control A Register (ch_num = 5)

pub const fn ctrlb5(&self) -> &Ctrlb5

0x114 - DMAC Channel Control B Register (ch_num = 5)

pub const fn cfg5(&self) -> &Cfg5

0x118 - DMAC Channel Configuration Register (ch_num = 5)

pub const fn wpmr(&self) -> &Wpmr

0x1e4 - DMAC Write Protect Mode Register

pub const fn wpsr(&self) -> &Wpsr

0x1e8 - DMAC Write Protect Status Register